@@ -5,6 +5,10 @@
 */
 
 #include "colorscheme.h"
+#include <kconfigwidgets_version.h>
+#if KCONFIGWIDGETS_VERSION >= QT_VERSION_CHECK(5, 93, 0)
+#include <KStatefulBrush> // was moved to own header in 5.93.0
+#endif
 
 ColorScheme::ColorScheme(QQuickItem *parent) :
 QQuickItem(parent)
