@@ -12,6 +12,7 @@
 #include <QDomDocument>
 #include <QTemporaryFile>
 
+#include <kwidgetsaddons_version.h>
 #include <KIO/FileCopyJob>
 #include <KIO/SimpleJob>
 #include <KJobWidgets>
@@ -613,7 +614,7 @@ bool ManagerPrivate::doQuery(const QUrl &url, QWidget *parent,
     QTemporaryFile tmpFile;
     if ( !tmpFile.open() ) {
         QString details = i18n("Unable to open temporary file.");
-        KMessageBox::detailedSorry(parent, UNABLE_TO_CONTACT.toString(), details);
+        KMessageBox::detailedError(parent, UNABLE_TO_CONTACT.toString(), details);
         return false;
     }
 
@@ -622,7 +623,7 @@ bool ManagerPrivate::doQuery(const QUrl &url, QWidget *parent,
     copyJob->exec();
     if( copyJob->error() ) {
         QString details = i18n("Server URL: %1", url.host());
-        KMessageBox::detailedSorry(parent, UNABLE_TO_CONTACT.toString(), details);
+        KMessageBox::detailedError(parent, UNABLE_TO_CONTACT.toString(), details);
         return false;
     }
 
@@ -645,14 +646,14 @@ bool ManagerPrivate::doQuery(const QUrl &url, QWidget *parent,
                 QString msg = i18n(attr.value().toLatin1());
                 QString caption = i18n("Message from world-wide highscores "
                                        "server");
-                KMessageBox::sorry(parent, msg, caption);
+                KMessageBox::error(parent, msg, caption);
                 return false;
             }
         }
     }
     QString msg = i18n("Invalid answer from world-wide highscores server.");
     QString details = i18n("Raw message: %1", content);
-    KMessageBox::detailedSorry(parent, msg, details);
+    KMessageBox::detailedError(parent, msg, details);
     return false;
 }
 
@@ -662,7 +663,7 @@ bool ManagerPrivate::getFromQuery(const QDomNamedNodeMap &map,
 {
     QDomAttr attr = map.namedItem(name).toAttr();
     if ( attr.isNull() ) {
-	    KMessageBox::sorry(parent,
+	    KMessageBox::error(parent,
                i18n("Invalid answer from world-wide "
                     "highscores server (missing item: %1).", name));
 		return false;
@@ -791,12 +792,21 @@ int ManagerPrivate::submitScore(const Score &ascore,
     QString newName;
     KMessageBox::ButtonCode dummy;
     if ( score.type()==Won && askIfAnonymous && _playerInfos->isAnonymous()
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+     && KMessageBox::shouldBeShownTwoActions(dontAskAgainName, dummy) ) {
+#else
      && KMessageBox::shouldBeShownYesNo(dontAskAgainName, dummy) ) {
+#endif
          AskNameDialog d(widget);
          if ( d.exec()==QDialog::Accepted ) newName = d.name();
          if ( d.dontAskAgain() )
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+             KMessageBox::saveDontShowAgainTwoActions(dontAskAgainName,
+                                                      KMessageBox::SecondaryAction);
+#else
              KMessageBox::saveDontShowAgainYesNo(dontAskAgainName,
                                                  KMessageBox::No);
+#endif
     }
 
     int rank = -1;
