@@ -11,13 +11,14 @@
 #include <QDebug>
 #include <QIcon>
 #include <QStatusBar>
-#include <QApplication>
 #include <QScreen>
 // KF
 #include <KActionCollection>
 #include <KLocalizedString>
 #include <KMessageBox>
+// KDEGames
 #include <KStandardGameAction>
+#include <kdegames_version.h>
 
 #include "commondefs.h"
 #include "kreversihumanplayer.h"
@@ -39,7 +40,11 @@ KReversiMainWindow::KReversiMainWindow(QWidget* parent, bool startDemo)
     memset(m_player, 0, sizeof(m_player));
 
     m_provider = new KgThemeProvider();
+#if KDEGAMES_VERSION >= QT_VERSION_CHECK(7, 4, 0)
+    m_provider->discoverThemes(QStringLiteral("pics"));
+#else
     m_provider->discoverThemes("appdata", QStringLiteral("pics"));
+#endif
 
     for (auto &label : m_statusBarLabel) {
        label = new QLabel(this);
